@@ -1,5 +1,8 @@
-class Meta:
+from __future__ import absolute_import, unicode_literals
+
+
+class Meta(object):
     """A simple object subclass to allow for a Meta class to be added
     to CompositeField if none is declared.
     """
-    pass
\ No newline at end of file
+    pass
